Plotting
========

Common
------

``colour.plotting``

.. currentmodule:: colour.plotting

.. autosummary::
    :toctree: generated/
    :template: class.rst

    ColourSwatch

.. currentmodule:: colour.plotting

.. autosummary::
    :toctree: generated/

    colour_style
    override_style
    colour_cycle
    artist
    camera
    render
    label_rectangles
    uniform_axes3d
    plot_single_colour_swatch
    plot_multi_colour_swatches
    plot_single_function
    plot_multi_functions
    plot_image

**Ancillary Objects**

``colour.plotting.common``

.. currentmodule:: colour.plotting.common

.. autosummary::
    :toctree: generated/

    KwargsArtist
    KwargsCamera
    KwargsRender
    font_scaling
    filter_passthrough
    filter_RGB_colourspaces
    filter_cmfs
    filter_illuminants
    filter_colour_checkers

Colorimetry
-----------

``colour.plotting``

.. currentmodule:: colour.plotting

.. autosummary::
    :toctree: generated/

    plot_single_sd
    plot_multi_sds
    plot_single_cmfs
    plot_multi_cmfs
    plot_single_illuminant_sd
    plot_multi_illuminant_sds
    plot_visible_spectrum
    plot_single_lightness_function
    plot_multi_lightness_functions
    plot_single_luminance_function
    plot_multi_luminance_functions
    plot_blackbody_spectral_radiance
    plot_blackbody_colours

Colour Vision Deficiency
------------------------

``colour.plotting``

.. currentmodule:: colour.plotting

.. autosummary::
    :toctree: generated/

    plot_cvd_simulation_Machado2009


Colour Characterisation
-----------------------

``colour.plotting``

.. currentmodule:: colour.plotting

.. autosummary::
    :toctree: generated/

    plot_single_colour_checker
    plot_multi_colour_checkers

Corresponding Chromaticities
----------------------------

``colour.plotting``

.. currentmodule:: colour.plotting

.. autosummary::
    :toctree: generated/

    plot_corresponding_chromaticities_prediction

CIE Chromaticity Diagrams
-------------------------

``colour.plotting``

.. currentmodule:: colour.plotting

.. autosummary::
    :toctree: generated/

    METHODS_CHROMATICITY_DIAGRAM
    LABELS_CHROMATICITY_DIAGRAM_DEFAULT
    lines_spectral_locus
    plot_chromaticity_diagram_CIE1931
    plot_chromaticity_diagram_CIE1960UCS
    plot_chromaticity_diagram_CIE1976UCS
    plot_sds_in_chromaticity_diagram_CIE1931
    plot_sds_in_chromaticity_diagram_CIE1960UCS
    plot_sds_in_chromaticity_diagram_CIE1976UCS

**Ancillary Objects**

``colour.plotting.diagrams``

.. currentmodule:: colour.plotting.diagrams

.. autosummary::
    :toctree: generated/

    plot_spectral_locus
    plot_chromaticity_diagram_colours
    plot_chromaticity_diagram
    plot_sds_in_chromaticity_diagram

Colour Models
-------------

``colour.plotting``

.. currentmodule:: colour.plotting

.. autosummary::
    :toctree: generated/

    plot_RGB_colourspaces_in_chromaticity_diagram_CIE1931
    plot_RGB_colourspaces_in_chromaticity_diagram_CIE1960UCS
    plot_RGB_colourspaces_in_chromaticity_diagram_CIE1976UCS
    plot_RGB_chromaticities_in_chromaticity_diagram_CIE1931
    plot_RGB_chromaticities_in_chromaticity_diagram_CIE1960UCS
    plot_RGB_chromaticities_in_chromaticity_diagram_CIE1976UCS
    plot_ellipses_MacAdam1942_in_chromaticity_diagram_CIE1931
    plot_ellipses_MacAdam1942_in_chromaticity_diagram_CIE1960UCS
    plot_ellipses_MacAdam1942_in_chromaticity_diagram_CIE1976UCS
    plot_single_cctf
    plot_multi_cctfs
    plot_constant_hue_loci

**Ancillary Objects**

``colour.plotting.models``

.. currentmodule:: colour.plotting.models

.. autosummary::
    :toctree: generated/

    colourspace_model_axis_reorder
    lines_pointer_gamut
    plot_pointer_gamut
    plot_RGB_colourspaces_in_chromaticity_diagram
    plot_RGB_chromaticities_in_chromaticity_diagram
    plot_ellipses_MacAdam1942_in_chromaticity_diagram

Colour Notation Systems
-----------------------

``colour.plotting``

.. currentmodule:: colour.plotting

.. autosummary::
    :toctree: generated/

    plot_single_munsell_value_function
    plot_multi_munsell_value_functions

Optical Phenomena
-----------------

``colour.plotting``

.. currentmodule:: colour.plotting

.. autosummary::
    :toctree: generated/

    plot_single_sd_rayleigh_scattering
    plot_the_blue_sky

Colour Quality
--------------

``colour.plotting``

.. currentmodule:: colour.plotting

.. autosummary::
    :toctree: generated/

    plot_single_sd_colour_rendering_index_bars
    plot_multi_sds_colour_rendering_indexes_bars
    plot_single_sd_colour_quality_scale_bars
    plot_multi_sds_colour_quality_scales_bars

**Ancillary Objects**

``colour.plotting.quality``

.. currentmodule:: colour.plotting.quality

.. autosummary::
    :toctree: generated/

    plot_colour_quality_bars

Gamut Section Plotting
----------------------

``colour.plotting``

.. currentmodule:: colour.plotting

.. autosummary::
    :toctree: generated/

    plot_visible_spectrum_section
    plot_RGB_colourspace_section

**Ancillary Objects**

``colour.plotting.section``

.. currentmodule:: colour.plotting.section

.. autosummary::
    :toctree: generated/

    plot_hull_section_colours
    plot_hull_section_contour

Colour Temperature & Correlated Colour Temperature
--------------------------------------------------

``colour.plotting``

.. currentmodule:: colour.plotting

.. autosummary::
    :toctree: generated/

    lines_daylight_locus
    LABELS_PLANCKIAN_LOCUS_DEFAULT
    lines_planckian_locus
    plot_planckian_locus_in_chromaticity_diagram_CIE1931
    plot_planckian_locus_in_chromaticity_diagram_CIE1960UCS
    plot_planckian_locus_in_chromaticity_diagram_CIE1976UCS

**Ancillary Objects**

``colour.plotting.temperature``

.. currentmodule:: colour.plotting.temperature

.. autosummary::
    :toctree: generated/

    plot_daylight_locus
    plot_planckian_locus
    plot_planckian_locus_in_chromaticity_diagram

Colour Models Volume
--------------------

``colour.plotting``

.. currentmodule:: colour.plotting

.. autosummary::
    :toctree: generated/

    plot_RGB_colourspaces_gamuts
    plot_RGB_scatter

ANSI/IES TM-30-18 Colour Rendition Report
-----------------------------------------

``colour.plotting``

.. currentmodule:: colour.plotting

.. autosummary::
    :toctree: generated/

    plot_single_sd_colour_rendition_report

**Ancillary Objects**

``colour.plotting.tm3018``

.. currentmodule:: colour.plotting.tm3018

.. autosummary::
    :toctree: generated/

    plot_single_sd_colour_rendition_report_full
    plot_single_sd_colour_rendition_report_intermediate
    plot_single_sd_colour_rendition_report_simple

Automatic Colour Conversion Graph
---------------------------------

``colour.plotting``

.. currentmodule:: colour.plotting

.. autosummary::
    :toctree: generated/

    plot_automatic_colour_conversion_graph
